import { Observable } from "rxjs";
import * as i0 from "@angular/core";
export interface DraftOptions<T = any> {
    id?: string;
    getOriginalModel?: () => Promise<T>;
}
export interface DraftSupport<T = any> {
    getDraft(options?: DraftOptions<T>): Draft<T>;
}
export declare class Draft<Model = unknown> {
    #private;
    private identifier;
    private persistFn;
    private getOriginalModel;
    /** Provides access to the current model as Observable */
    get model$(): Observable<Model>;
    get originalModel$(): Observable<Model>;
    changes$: Observable<import("deep-diff").Diff<Model, Model>[]>;
    changesCount$: Observable<number>;
    constructor(identifier: string, persistFn: (entity: Model) => Promise<Model>, getOriginalModel: () => Promise<Model>);
    /** Returns a snapshot of the current draft. Changes will not mutate the current draft! */
    getSnapshot(): Model;
    /** Persists the current draft via api */
    persist(): Promise<Model>;
    /** Completely overwrites the changes model */
    set(delta: Model): void;
    /** Overwrites a sub property of the changed model, supports dot notation */
    setProperty(propertyName: string, delta: any): void;
    /** Overwrites a sub property of the original model, supports dot notation */
    setOriginalProperty(propertyName: string, value: any): void;
    /** Removes a sub property of the changes model, supports dot notation */
    removeProperty(propertyName: string): void;
    /** Resets the current draft */
    reset(): void;
    resetOriginalModel(): Promise<void>;
}
/**
 * The DraftService stores one or more entities grouped by an identifier in the browsers local storage.
 * It can be used for synchronizing an entities state across several ui components or to persist a (ui) state across
 * browser reloads.
 */
export declare class DraftService {
    #private;
    /**
     * Returns a draft for the given identifier. Identifier might get prefixed by various implementations,
     * and postfixed if id is given.
     */
    getDraftFor<Model>(identifier: string, options?: DraftOptions<Model>): Draft<Model>;
    /**
     * Configures drafts
     *
     * @param typeName type name, something like "application"
     * @param saveFn the function to call when the draft needs to get persisted
     */
    configureDraft<Model>(typeName: string, saveFn: (model: Model) => Promise<Model>): void;
    protected getDraftPrefix(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<DraftService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DraftService>;
}
