import { ComponentType } from "@angular/cdk/portal";
import { InjectionToken } from "@angular/core";
import { InlineTranslation } from "@smallstack/i18n-shared";
import { SearchQuery, SmallstackType, SmallstackTypeSchema, TypeRegistry } from "@smallstack/typesystem";
export declare const FRONTEND_TYPE_REGISTRY: InjectionToken<IFrontendTypeRegistry>;
export interface FrontendSmallstackType extends SmallstackType {
    /**
     * @deprecated Use TypeConfiguration->Views
     * The editor component will be used for creating and editing models. It has to be a dialog component that accepts {@link EditorDialogData} as data.
     */
    getEditorComponent?: () => Promise<ComponentType<unknown>>;
    /**
     * @deprecated Use TypeConfiguration->Views
     * The detail component will be used for displaying models. It has to be a dialog component that accepts {@link DetailDialogData} as data.
     */
    getDetailComponent?: () => Promise<ComponentType<unknown>>;
    getCount(query: SearchQuery): Promise<number>;
}
export interface OpenEditorOptions {
    /** Schema for the editor dialog. If empty, full type schema will be used */
    schema?: SmallstackTypeSchema;
    /** Will override the default title of the editor dialog */
    title?: string | InlineTranslation;
}
export interface IFrontendTypeRegistry extends TypeRegistry<FrontendSmallstackType> {
    getSchema(typePath: string): Promise<SmallstackTypeSchema>;
    /** Opens the related editor and returns the edited/created model */
    openEditor(typePath: string, model?: any, options?: OpenEditorOptions): Promise<any>;
    openDetail(type: string | FrontendSmallstackType, model: any, options?: {
        asPopup?: boolean;
        context?: any;
    }): Promise<any>;
}
