import { Params } from "@angular/router";
export interface WebComponentService {
    /**
     * Extracts the current URL query string of the Cloud Backoffice for the usage within a WebComponent, AngularComponents, etc.
     *
     * @returns {Params}
     * @memberof WebComponentService
     */
    getNavigationParams(): Params;
    /**
     * Method used for navigation from a WebComponent to another part of Cloud Backoffice, since the WebComponent itself does not have access to the Angular Router of the Cloud Backoffice.
     *
     * @param {string} targetPath path to navigate to in Cloud Backoffice. Will be appended to the current project path
     * @param {string} [queryParams] URL query parameters which are appended to navigation target
     * @returns {Promise<void>}
     * @memberof WebComponentService
     */
    navigateFromWebComponent(targetPath: string, queryParams?: Params): Promise<void>;
}
